==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE18S.sql <==
/****************************************************************************/
/* GE18 ( 位置情報管理ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE18 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , LOC_GRP      varchar           (   30 )                  NOT NULL            /*  20 位置ｸﾞﾙｰﾌﾟ   */
 , LOC_KEY      varchar           (   30 )                  NOT NULL            /*  30 固有ID       */
 , LOC_COL      float                           DEFAULT 0   NOT NULL            /*  40 列位置       */
 , LOC_ROW      float                           DEFAULT 0   NOT NULL            /*  50 行位置       */
 , NAME_JA      varchar           (  200 )                                      /*  60 名称         */
 , LABEL_NAME   varchar           (   60 )                                      /*  70 表示名称     */
 , BIKO         varchar           ( 2000 )                                      /*  80 備考         */
 , ICON         varchar           (  200 )                                      /*  90 ｱｲｺﾝ         */
 , R_KEY1       varchar           (   30 )                                      /* 100 連結ｷｰ1      */
 , R_KEY2       varchar           (   30 )                                      /* 110 連結ｷｰ2      */
 , R_KEY3       varchar           (   30 )                                      /* 120 連結ｷｰ3      */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE18S.sql <==
/****************************************************************************/
/* GE18 ( 位置情報管理ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE18 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , LOC_GRP      varchar           (   30 )                  NOT NULL            /*  20 位置ｸﾞﾙｰﾌﾟ   */
 , LOC_KEY      varchar           (   30 )                  NOT NULL            /*  30 固有ID       */
 , LOC_COL      float                           DEFAULT 0   NOT NULL            /*  40 列位置       */
 , LOC_ROW      float                           DEFAULT 0   NOT NULL            /*  50 行位置       */
 , NAME_JA      varchar           (  200 )                                      /*  60 名称         */
 , LABEL_NAME   varchar           (   60 )                                      /*  70 表示名称     */
 , BIKO         varchar           ( 2000 )                                      /*  80 備考         */
 , ICON         varchar           (  200 )                                      /*  90 ｱｲｺﾝ         */
 , R_KEY1       varchar           (   30 )                                      /* 100 連結ｷｰ1      */
 , R_KEY2       varchar           (   30 )                                      /* 110 連結ｷｰ2      */
 , R_KEY3       varchar           (   30 )                                      /* 120 連結ｷｰ3      */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 作成日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
